.. contents::

Introduction
============

Mail content type for document management system

Tests
=====

This add-on is tested using Travis CI. The current status of the add-on is :

.. image:: https://secure.travis-ci.org/collective/collective.dms.mailcontent.png
    :target: http://travis-ci.org/collective/collective.dms.mailcontent
